### Model Quality Evaluation Capabilities

At this time, we support evaluation for various supervised ML models.
The following evaluations have been added at this time:

1. Regression Models: For cases where the target variable is a
continuous function of dependent variables.

2. Classification Models: For cases where the target variable is a
discrete function, and consists of a (usually small) finite set of
values, called the classes. We support the following specific cases:
 * Binary Classification: Target consists of two unique values
 * Multi-class Classification: Target consists of more than two
 (but definitely finite) unique values.
